"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.processAttribute = void 0;
const html_validate_1 = require("html-validate");
const directives = [
    "checked",
    "class",
    "disabled",
    "href",
    "maxlength",
    "minlength",
    "pattern",
    "readonly",
    "required",
    "selected",
    "src",
    "style",
    "value",
];
const matchNgAttr = new RegExp(`^ng-(?:attr-(.*)|(${directives.join("|")}))$`);
/**
 * Handle ng-xyz and ng-attr-xyz attributes.
 *
 * It yields both the original attribute (as-is) and an aliased attribute
 * xyz. E.g. ng-src="{{ foo }}" yields both:
 *
 * - ng-src="{{ foo }}"
 * - src="DynamicValue"
 */
function* processNgAttr(attr, key) {
    /* passthru original attribute */
    yield attr;
    /* setup ng-attr-x alias */
    yield Object.assign({}, attr, {
        key,
        value: new html_validate_1.DynamicValue(attr.value),
        originalAttribute: attr.key,
    });
}
function* processAttribute(attr) {
    const ngAttr = attr.key.match(matchNgAttr);
    if (ngAttr) {
        yield* processNgAttr(attr, ngAttr[1] || ngAttr[2]);
        return;
    }
    /* test if attribute contains interpolation */
    if (typeof attr.value === "string" && attr.value.match(/{{.*}}/)) {
        yield Object.assign({}, attr, {
            value: new html_validate_1.DynamicValue(attr.value),
        });
        return;
    }
    /* passthru original attribute */
    yield attr;
}
exports.processAttribute = processAttribute;
