"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const html_validate_1 = require("html-validate");
const test_utils_1 = require("html-validate/test-utils");
const attribute_1 = require("./attribute");
const transform_1 = require("./transform");
it("should extract template from components", () => {
    expect.assertions(2);
    const result = test_utils_1.transformFile(transform_1.angularTransformJS, "./test/component.js");
    expect(result).toHaveLength(1);
    expect(result[0]).toMatchInlineSnapshot(`
		Object {
		  "column": 12,
		  "data": "<p>foo</i>",
		  "filename": "./test/component.js",
		  "hooks": Object {
		    "processAttribute": [Function],
		    "processElement": [Function],
		  },
		  "line": 2,
		  "offset": 42,
		  "originalData": "<p>foo</i>",
		}
	`);
});
it("should extract templates from routes", () => {
    expect.assertions(4);
    const result = test_utils_1.transformFile(transform_1.angularTransformJS, "./test/route.js");
    expect(result).toHaveLength(3);
    expect(result[0]).toMatchInlineSnapshot(`
		Object {
		  "column": 31,
		  "data": "<p>foo</i>",
		  "filename": "./test/route.js",
		  "hooks": Object {
		    "processAttribute": [Function],
		    "processElement": [Function],
		  },
		  "line": 3,
		  "offset": 93,
		  "originalData": "<p>foo</i>",
		}
	`);
    expect(result[1]).toMatchInlineSnapshot(`
		Object {
		  "column": 14,
		  "data": "
						<button>
							bar
						</button>
					",
		  "filename": "./test/route.js",
		  "hooks": Object {
		    "processAttribute": [Function],
		    "processElement": [Function],
		  },
		  "line": 5,
		  "offset": 137,
		  "originalData": "
						<button>
							bar
						</button>
					",
		}
	`);
    expect(result[2]).toMatchInlineSnapshot(`
		Object {
		  "column": 14,
		  "data": "<button type=\\"{{     }}\\"></button>",
		  "filename": "./test/route.js",
		  "hooks": Object {
		    "processAttribute": [Function],
		    "processElement": [Function],
		  },
		  "line": 12,
		  "offset": 226,
		  "originalData": "<button type=\\"{{valid}}\\"></button>",
		}
	`);
});
it("should extract template from html file", () => {
    expect.assertions(2);
    const result = test_utils_1.transformFile(transform_1.angularTransformHTML, "./test/template.html");
    expect(result).toHaveLength(1);
    expect(result[0]).toMatchInlineSnapshot(`
		Object {
		  "column": 1,
		  "data": "<div>
			<button></button>
			<button type=\\"invalid\\"></button>
			<button type=\\"{{       }}\\"></button>
			<button ng-attr-type=\\"valid\\"></button>
		</div>

		<!-- should detect duplicated ng-class but not duplicate class + ng-class -->
		<p class=\\"foo\\" ng-class=\\"bar\\"></p>
		<p ng-class=\\"foo\\" ng-class=\\"bar\\"></p>

		<!-- should detect ng-bind and friends as having textual content -->
		<h1></h1>
		<h2 ng-bind=\\"foo\\"></h2>
		<h3 ng-bind-html=\\"bar\\"></h3>
		<h3 ng-bind-template=\\"baz\\"></h3>
		<h4 translate=\\"KEY\\"></h4>

		<h1 ng-transclude></h1>
		<h1><ng-transclude></ng-transclude></h1>
		<h1 ng-pluralize></h1>
		<h1><ng-pluralize></ng-pluralize></h1>

		<!-- should not detect errors inside {{     }}  -->
		<div>{{        }}</div>
		<div>{{                               }}</div>
		",
		  "filename": "./test/template.html",
		  "hooks": Object {
		    "processAttribute": [Function],
		    "processElement": [Function],
		  },
		  "line": 1,
		  "offset": 0,
		  "originalData": "<div>
			<button></button>
			<button type=\\"invalid\\"></button>
			<button type=\\"{{ valid }}\\"></button>
			<button ng-attr-type=\\"valid\\"></button>
		</div>

		<!-- should detect duplicated ng-class but not duplicate class + ng-class -->
		<p class=\\"foo\\" ng-class=\\"bar\\"></p>
		<p ng-class=\\"foo\\" ng-class=\\"bar\\"></p>

		<!-- should detect ng-bind and friends as having textual content -->
		<h1></h1>
		<h2 ng-bind=\\"foo\\"></h2>
		<h3 ng-bind-html=\\"bar\\"></h3>
		<h3 ng-bind-template=\\"baz\\"></h3>
		<h4 translate=\\"KEY\\"></h4>

		<h1 ng-transclude></h1>
		<h1><ng-transclude></ng-transclude></h1>
		<h1 ng-pluralize></h1>
		<h1><ng-pluralize></ng-pluralize></h1>

		<!-- should not detect errors inside {{ ... }}  -->
		<div>{{ \\"</p>\\" }}</div>
		<div>{{ foo && bar ? 'true' : 'false' }}</div>
		",
		}
	`);
});
it("querySelector should find class with ng-class present", () => {
    expect.assertions(3);
    const parser = new html_validate_1.Parser(html_validate_1.Config.empty());
    const source = {
        data: '<p class="foo" ng-class="bar"></p>',
        filename: "inline",
        line: 1,
        column: 1,
        offset: 0,
        hooks: {
            processAttribute: attribute_1.processAttribute,
        },
    };
    const doc = parser.parseHtml(source);
    const node = doc.querySelector(".foo");
    expect(node).toBeInstanceOf(html_validate_1.HtmlElement);
    expect(Array.from(node.classList)).toEqual(["foo"]);
    expect(node.getAttribute("class", true)).toEqual([
        expect.objectContaining({
            key: "class",
            value: "foo",
        }),
        expect.objectContaining({
            key: "class",
            value: expect.any(html_validate_1.DynamicValue),
            originalAttribute: "ng-class",
        }),
    ]);
});
it("should strip templating from html", () => {
    expect.assertions(2);
    const result = test_utils_1.transformString(transform_1.angularTransformHTML, "<p>{{ foobar }}</p>");
    expect(result).toHaveLength(1);
    expect(result[0]).toMatchInlineSnapshot(`
		Object {
		  "column": 1,
		  "data": "<p>{{        }}</p>",
		  "filename": "inline",
		  "hooks": Object {
		    "processAttribute": [Function],
		    "processElement": [Function],
		  },
		  "line": 1,
		  "offset": 0,
		  "originalData": "<p>{{ foobar }}</p>",
		}
	`);
});
it("should strip templating from js", () => {
    expect.assertions(2);
    const result = test_utils_1.transformString(transform_1.angularTransformJS, "const c = { template: '<p>{{ foobar }}</p>' };");
    expect(result).toHaveLength(1);
    expect(result[0]).toMatchInlineSnapshot(`
		Object {
		  "column": 23,
		  "data": "<p>{{        }}</p>",
		  "filename": "inline",
		  "hooks": Object {
		    "processAttribute": [Function],
		    "processElement": [Function],
		  },
		  "line": 1,
		  "offset": 23,
		  "originalData": "<p>{{ foobar }}</p>",
		}
	`);
});
